@@ -4,7 +4,7 @@ __copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('LanguageField', 'SimpleLanguageField')
 
-from six import PY2
+from six import PY3
 
 from django.db import models
 from django.core import exceptions
@@ -159,7 +159,7 @@ class LanguageField(models.CharField):
                 :return str:
                 """
                 if self.translation_of:
-                    if PY2:
+                    if not PY3:
                         url_title = unicode(self.translation_of)
                     else:
                         url_title = self.translation_of
@@ -194,7 +194,7 @@ class LanguageField(models.CharField):
                     # Processing all available translations. Adding edit links.
                     if available_translations:
                         for translation in available_translations:
-                            if PY2:
+                            if not PY3:
                                 url_title = unicode(languages[translation.language])
                             else:
                                 url_title = languages[translation.language]
@@ -218,7 +218,7 @@ class LanguageField(models.CharField):
                                 self._meta.module_name,
                                 '?translation_of=%s&amp;language=%s' % (str(original_translation.id), language)
                                 )
-                        if PY2:
+                        if not PY3:
                             name = unicode(languages[language])
                         else:
                             name = languages[language]
