@@ -1,7 +1,7 @@
 __title__ = 'slim.translations'
-__version__ = '0.7'
-__build__ = 0x000007
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('short_language_code', 'is_primary_language')
 
 from django.utils import translation
